summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotePixmapFactory.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit3fcef18c75f7cd751ed706c12977230242fb817d (patch)
treea94c2497a3923ed9972e71c5bbba0697882c1427 /src/gui/editors/notation/NotePixmapFactory.cpp
parent80ee419f074dc252449791628d4584b5c0ea0c9b (diff)
downloadrosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.tar.gz
rosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/editors/notation/NotePixmapFactory.cpp')
-rw-r--r--src/gui/editors/notation/NotePixmapFactory.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/editors/notation/NotePixmapFactory.cpp b/src/gui/editors/notation/NotePixmapFactory.cpp
index e5f306b..ac9064a 100644
--- a/src/gui/editors/notation/NotePixmapFactory.cpp
+++ b/src/gui/editors/notation/NotePixmapFactory.cpp
@@ -1261,7 +1261,7 @@ NotePixmapFactory::drawFlags(int flagCount,
} else {
// No problem with tqmask here
m_p->drawNoteCharacter(m_left + s1.x() - hotspot.x(),
y,
flagChar);
@@ -2890,7 +2890,7 @@ NotePixmapFactory::drawOttavaAux(int length, int octavesUp,
m_p->beginExternal(painter);
painter->translate(x - backpedal, y - height);
} else {
- NOTATION_DEBUG << "NotePixmapFactory::drawOttavaAux: making pixmap and tqmask " << width << "x" << height << endl;
+ NOTATION_DEBUG << "NotePixmapFactory::drawOttavaAux: making pixmap and mask " << width << "x" << height << endl;
createPixmapAndMask(width, height);
}
@@ -3443,7 +3443,7 @@ NotePixmapFactory::createPixmapAndMask(int width, int height,
total += width * height;
// NOTATION_DEBUG << "createPixmapAndMask: " << width << "x" << height << " (" << (width*height) << " px, " << total << " total)" << endl;
// clear up pixmap and tqmask
m_generatedPixmap->fill();
m_generatedMask->fill(TQt::color0);
@@ -1261,7 +1261,7 @@ NotePixmapFactory::drawFlags(int flagCount,
} else {
- // No problem with tqmask here
+ // No problem with mask here
m_p->drawNoteCharacter(m_left + s1.x() - hotspot.x(),
y,
@@ -3443,7 +3443,7 @@ NotePixmapFactory::createPixmapAndMask(int width, int height,
total += width * height;
// NOTATION_DEBUG << "createPixmapAndMask: " << width << "x" << height << " (" << (width*height) << " px, " << total << " total)" << endl;
- // clear up pixmap and tqmask
+ // clear up pixmap and mask
m_generatedPixmap->fill();
m_generatedMask->fill(TQt::color0);